import json
import os
from bidict import bidict


def _set_genre_cache():
    dirname = os.path.join(os.path.dirname(__file__), 'paylogic_genres.json')
    genre_file = open(dirname)
    genres = json.load(genre_file)
    genre_file.close()
    return genres, bidict([(genre_code, genres[genre_code]['ecc']) for genre_code in genres])


def convert_ecc_to_code(ecc):
    return _GENRE_CACHE[:ecc]


def convert_code_to_ecc(code):
    return _GENRE_CACHE[code]


GENRE_DEFINITIONS, _GENRE_CACHE = _set_genre_cache()



"""Paylogic genres Python library."""

import os


def get_supported_languages():
    """Get supported i18n languages."""
    basedir = os.path.join(os.path.dirname(__file__), 'locale')
    return [
        unicode(name) for name in os.listdir(basedir)
        if os.path.isdir(os.path.join(basedir, name))
    ]



#!/usr/bin/env python

import os
from setuptools import setup, Command


class ExportJSON(Command):
    """Export i18n genres json."""

    user_options = []

    def initialize_options(self):
        self.cwd = None

    def finalize_options(self):
        self.cwd = os.getcwd()

    def run(self):
        from scripts.export import export_genres
        dirname = os.path.dirname(__file__)
        export_genres(
            source=os.path.join(dirname, 'src', 'paylogic_genres.json'),
            output=os.path.join(dirname, 'paylogic_genres.json'),
        )
        export_genres(
            source=os.path.join(dirname, 'src', 'paylogic_genres.json'),
            output=os.path.join(dirname, 'paylogic_genres', 'paylogic_genres.json'),
        )

kwargs = {}

# Detect the "make" mode
try:
    import babel
    babel
    kwargs.setdefault('entry_points', {})

    kwargs['entry_points']['babel.extractors'] = ['genres = scripts.extract:extract_genres']

    kwargs['message_extractors'] = {
        '': [
            ('src/paylogic_genres.json', 'genres', None),
        ],
    }
except ImportError:
    pass


setup(
    name='paylogic-genres',
    description='Genre classification used by Paylogic.',
    #long_description=__doc__,
    author='Paylogic',
    license='MIT license',
    version='1.0.0',
    cmdclass={
        'export_json': ExportJSON,
    },
    url='https://github.com/paylogic/genres',
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
    ],
    packages=['paylogic_genres'],
    package_data={
        '': [
            'locale/*/*/*',
            'paylogic_genres.json',
        ]
    },
    install_requires=[
        'bidict',
    ],
    **kwargs
)
